@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.6.10';
+$Git::Hooks::VERSION = '1.6.11';
 use 5.010;
 use strict;
 use warnings;
@@ -380,7 +380,7 @@ sub _prepare_gerrit_args {
     # used if one sets up Gerrit hooks, which may not be the most
     # common usage of Git::Hooks.
     eval {require Gerrit::REST}
-        or die __PACKAGE__, ": Can't require Gerrit::REST module.\n";
+        or die __PACKAGE__, ": Please, install the Gerrit::REST module to use Gerrit hooks.\n";
 
     $opt{gerrit} = do {
         my %info;
@@ -683,7 +683,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.6.10
+version 1.6.11
 
 =head1 SYNOPSIS
 
